{% extends "simpl/base.html" %}

{% block main_wrap_classes %}v-nav-flex-layout{% endblock %}

{% block heading %}{% if run.ended %}Restart {% else %}End{% endif %} Gameplay{% endblock %}

{% block arrows %}
{% include 'simpl/includes/status-arrows.html' %}
{% endblock arrows %}


{% block content_inner %}
{{ block.super }}
  {% include 'simpl/includes/form_end.html' %}
{% endblock %}
